/**
 * copyright area
 */

import org.objectweb.util.monolog.api.LoggerFactory;
import org.objectweb.util.monolog.api.HandlerFactory;
import org.objectweb.util.monolog.api.LevelFactory;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.util.monolog.file.monolog.PropertiesConfAccess;

import java.util.Properties;
import java.io.FileInputStream;

/**
 * @author S.Chassande-Barrioz
 */
public class RollingFile {
    public static void main(String[] args) {
		if (args.length < 1) {
			System.out.println("Syntax error !");
			System.out.println(
				"java Simple <monolog file name> [-useClassPath]");
			System.exit(1);
		}
		LoggerFactory lf = null;
		try {
			lf = initMonolog(args);
		}
		catch (Exception e) {
			e.printStackTrace();
			System.exit(-1);
		}
		RollingFile s = new RollingFile();
		s.setLogger(lf.getLogger("monolog.examples.RollingFile"));
		s.foo();
	}

	public static LoggerFactory initMonolog(String[] args) throws Exception {
		if (args[0].length() == 0) {
			throw new Exception(
				"impossible to configure monolog without configuration file");
		}
		debug("monolog configuration file:" + args[0]);
		// Load the configuration in a Properties object
		String b = (args.length>2 ? args[1] : "");
		debug("use class path to found file:" + b);
		Properties p = new Properties();
		if ("true".equalsIgnoreCase(b)) {
			p.load(ClassLoader.getSystemResourceAsStream(args[0]));
		}
		else {
			p.load(new FileInputStream(args[0]));
		}

		// Search the class name of the LoggerFactory which must be instanciated
		b = p.getProperty("log.config.classname", null);
		if (b == null) {
			throw new Exception("Malformed configuration log file:"
				+ " log.config.classname not available");
		}

		// Instanciate the LoggerFactory
		LoggerFactory lf = (LoggerFactory) Class.forName(b).newInstance();

		// Configure with the properties
		PropertiesConfAccess.load(p, lf, (HandlerFactory) lf, (LevelFactory) lf);

		return lf;
	}

	protected Logger logger = null;

	public RollingFile() {
	}

	public void setLogger(Logger l) {
		logger = l;
	}

	public void foo() {
        for (int i=0; i<5000; i++)
            logger.log(BasicLevel.DEBUG, "hello world");
	}

	private static void debug(String m) {
		//System.out.println(m);
	}

}
