/**
 * Copyright (C) 2002
 */

import org.objectweb.util.monolog.wrapper.common.Configurable;
import org.objectweb.util.monolog.api.LoggerFactory;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;

import java.util.Properties;

/**
 *
 * @author Sebastien Chassande-Barrioz
 */
public class SpecificConf {

	public static void main(String[] args) {
		if (args.length < 1) {
			System.out.println("Syntax error !");
			System.out.println(
				"java SpecificConf <logger factory class name> <mode> "
				+ "[<config file name> [ true | false ]]");
			System.exit(1);
		}
		LoggerFactory lf = null;
		try {
			lf = initMonolog(args);
		}
		catch (Exception e) {
			e.printStackTrace();
			System.exit(-1);
		}
		SpecificConf sc = new SpecificConf();
		sc.setLogger(lf.getLogger("monolog.examples.SpecificConf"),(lf.getLoggers())[0]);
		sc.foo();
		sc.bar();
	}

	public static LoggerFactory initMonolog(String[] args) throws Exception {
		// Instanciate the logger factory
		LoggerFactory lf = null;
		try {
			lf = (LoggerFactory) Class.forName(args[0]).newInstance();
		}
		catch (ClassCastException e) {
			throw new ClassCastException(
				"The specified class is not a Logger factory: " + args[0]);
		}
		catch (Exception e) {
			throw new ClassCastException(
				"Logger factory class is not availlable: " + args[0]);
		}

		String mode = (args.length>1 ? args[1] : null);
		Properties prop = null;
		if (mode != null && !mode.equalsIgnoreCase("null")) {
			String configFileName = (args.length>2 ? args[2] : null);
			prop = new Properties();
			prop.put(Configurable.LOG_CONFIGURATION_TYPE, mode);
			if (configFileName != null) {
				prop.put(Configurable.LOG_CONFIGURATION_FILE, configFileName);
			}

			String useClassPath = (args.length>3 ? args[3] : null);
			if (useClassPath != null) {
				prop.put(Configurable.LOG_CONFIGURATION_FILE_USE_CLASSPATH,
					useClassPath);
			}
		}
		try {
			((Configurable) lf).configure(prop);
		}
		catch (Exception e) {
			System.out.println("Impossible to configure in " + mode + " mode: "
				+ e.getMessage());
			System.exit(1);
		}
		return lf;
	}

	protected Logger logger = null;
	protected Logger root = null;

	public SpecificConf() {
	}

	public void setLogger(Logger l, Logger r ) {
		logger = l;
        root= r;
	}

	public void foo() {
        root.log(BasicLevel.DEBUG, "foo : hello my root logger");
		logger.log(BasicLevel.INFO, "foo : hello my favourite logger");
	}

	public void bar() {
        root.log(BasicLevel.WARN, "bar : root warning !");
		logger.log(BasicLevel.ERROR, "This is a throwed exception",
			new Throwable().fillInStackTrace());
	}

}
