/**
 * Copyright (C) 2002
 */

package org.objectweb.util.monolog.wrapper.log4j;

import org.objectweb.util.monolog.api.Handler;
import org.objectweb.util.monolog.api.HandlerFactory;
import org.apache.log4j.PatternLayout;
import org.apache.log4j.ConsoleAppender;

import java.util.HashMap;
import java.util.Map;
import java.io.OutputStreamWriter;

/**
 *
 * @author Sebastien Chassande-Barrioz
 */
public class ConsoleHandler extends ConsoleAppender implements Handler {

	/**
	 * This fields contains the properties of the Handler
	 */
	protected HashMap prop = null;

	/**
	 * It Builds a new MonologFileHandler. It is needed to specify an handler
	 * type.
	 * @param ht 	is the handler type. The possible values are the
	 * 				HandlerFactory.FILE_HANDLER_TYPE or
	 * 				HandlerFactory.CONSOLE_HANDLER_TYPE.
	 */
	public ConsoleHandler(String name) {
		super();
		setName(name);
		prop = new HashMap();
	}

	public Map getAttributes() {
		return prop;
	}

	public void setAttributes(Map attributes) {
		prop.clear();
		prop.putAll(attributes);
	}

	// IMPLEMENTATION OF THE Handler INTERFACE //
	//---------------------------------------------//

	public byte getType() {
		return Handler.CONSOLE_HANDLER_TYPE;
	}

	public String[] getAttributeNames() {
		return (String[]) prop.keySet().toArray(new String[0]);
	}

	public Object getAttribute(String key) {
		return prop.get(key);
	}

	public Object setAttribute(String key, Object value) {
		if (prop == null)
			prop = new HashMap();
		Object res = prop.put(key, value);
		if (key.equalsIgnoreCase(Handler.OUTPUT_ATTRIBUTE)) {
			super.target = (String) value;
			if (((String) value).equalsIgnoreCase("System.out")) {
				setWriter(new OutputStreamWriter(System.out));
			}
			else if (((String) value).equalsIgnoreCase("System.err")) {
				setWriter(new OutputStreamWriter(System.err));
			}
		}
		else if (key.equalsIgnoreCase(Handler.PATTERN_ATTRIBUTE)) {
			setLayout(
				new PatternLayout(
					PatternConverter.monolog2log4j((String) value)));
		}
		return res;
	}

}

